@@ -3,13 +3,20 @@ from rekuest.actors.base import Actor
 from rekuest.api.schema import LogLevelInput
 from rekuest.messages import Assignation, Provision
 from koil import unkoil
+from rekuest.agents.transport.base import AgentTransport
 
 
 class AssignationHelper(BaseModel):
     assignation: Assignation
+    transport: AgentTransport
 
     async def alog(self, level: LogLevelInput, message: str) -> None:
-        raise NotImplementedError()
+        await self.transport.log_to_assignation(
+            id=self.assignation.assignation, level=level, message=message
+        )
+
+    def log(self, level: LogLevelInput, message: str) -> None:
+        return unkoil(self.alog, level, message)
 
     async def aprogress(self, progress: int) -> None:
         raise NotImplementedError()
@@ -24,30 +31,13 @@ class AssignationHelper(BaseModel):
 
 class ProvisionHelper(BaseModel):
     provision: Provision
+    transport: AgentTransport
 
     async def alog(self, level: LogLevelInput, message: str) -> None:
-        raise NotImplementedError()
+        await self.transport.log_to_provision(
+            id=self.provision.provision, level=level, message=message
+        )
 
     @property
     def guardian(self) -> str:
         return self.provision.guardian
-
-
-class ThreadedAssignationHelper(AssignationHelper):
-    def progress(self, progress: int) -> None:
-        unkoil(self.aprogress, progress=progress)
-
-
-class AsyncAssignationHelper(AssignationHelper):
-    async def alog(self, message: str, level: LogLevelInput = LogLevelInput.DEBUG):
-
-        await self.actor.transport.log_to_assignation(
-            id=self.assignation.assignation, level=level, message=message
-        )
-
-
-class AsyncProvisionHelper(ProvisionHelper):
-    async def alog(self, message: str, level: LogLevelInput = LogLevelInput.DEBUG):
-        await self.actor.transport.log_to_provision(
-            id=self.actor.provision.id, level=level, message=message
-        )
